@@ -4,6 +4,7 @@ use Carp qw(confess);
 use Net::Braintree::Validations qw(verify_params credit_card_signature);
 use Net::Braintree::Util qw(validate_id);
 use Net::Braintree::Result;
+use Try::Tiny;
 
 has 'gateway' => (is => 'ro');
 
@@ -15,19 +16,30 @@ sub create {
 
 sub delete {
   my ($self, $token) = @_;
-  $self->_make_request("/payment_methods/$token", "delete", undef);
+  $self->_make_request("/payment_methods/credit_card/$token", "delete", undef);
 }
 
 sub update {
   my ($self, $token, $params) = @_;
   confess "ArgumentError" unless verify_params($params, credit_card_signature);
-  $self->_make_request("/payment_methods/$token", "put", {credit_card => $params});
+  $self->_make_request("/payment_methods/credit_card/$token", "put", {credit_card => $params});
 }
 
 sub find {
   my ($self, $token) = @_;
   confess "NotFoundError" unless validate_id($token);
-  $self->_make_request("/payment_methods/$token", "get", undef)->credit_card;
+  $self->_make_request("/payment_methods/credit_card/$token", "get", undef)->credit_card;
+}
+
+sub from_nonce {
+  my ($self, $nonce) = @_;
+  confess "NotFoundError" unless validate_id($nonce);
+
+  try {
+    return $self->_make_request("/payment_methods/from_nonce/$nonce", "get", undef)->credit_card;
+  } catch {
+    confess "Payment method with nonce $nonce locked, consumed or not found";
+  }
 }
 
 sub _make_request {
