@@ -1,5 +1,7 @@
 package Net::Braintree::Subscription;
 use Net::Braintree::SubscriptionGateway;
+use Net::Braintree::Subscription::Status;
+
 use Moose;
 extends 'Net::Braintree::ResultObject';
 
@@ -37,6 +39,16 @@ sub retry_charge {
   $class->gateway->transaction->retry_subscription_charge($subscription_id, $amount);
 }
 
+sub search {
+  my($class, $block) = @_;
+  $class->gateway->subscription->search($block);
+}
+
+sub all {
+  my $class = shift;
+  $class->gateway->subscription->all;
+}
+
 sub gateway {
   return Net::Braintree->configuration->gateway;
 }
